A enterprise framework for developing true enterprise python applications
===============================================================================
This project is designed to make building python applications to be used in enterprise systems.
There are many frameworks that exist for creating python web applications and/or APIs using python.  However,
the needs of enterprise level applications are often not met by these frameworks. Namely:

* API level calls for all operations
* CLI to perform automated/scripting tasks against the application

PyLegos borrows many of the concepts used by other application frameworks.  The framework is somewhat opinionated.  It
currently requires a particular file structure.  In future releases we hope to eliminate this requirement so that the
structure can be adjusted to meet the style of the development team.


